dupin.data.reduce
---------------------------

.. rubric:: Overview

.. py:currentmodule:: dupin.data.reduce

.. autosummary::
    :nosignatures:

    CustomReducer
    NthGreatest
    Percentile
    Tee

.. rubric:: Details

.. automodule:: dupin.data.reduce
    :members: CustomReducer,
        NthGreatest,
        Percentile,
        Tee
